@@ -169,10 +169,17 @@ def _is_appdata_object(in_object):
 
 
 def std_namer(name):
-    _nameparts = name.replace('.log', '').split('.')
-    _path, _basename = pathmaker(_nameparts[0]).rsplit('/', 1)
-    extra_nameparts = '_'.join([_nameparts[i] for i in range(len(_nameparts)) if i != 0])
-    return pathmaker(_path, 'old_logs', f'{_basename}_{extra_nameparts}.log')
+    dir_path = os.path.dirname(name)
+    new_dir_path = pathmaker(dir_path, 'old_logs')
+    file_name = os.path.basename(name)
+    file_number = 1
+    new_file_name = file_name.replace('.log', f"_{str(file_number)}.log")
+    new_path = pathmaker(new_dir_path, new_file_name)
+    while os.path.exists(new_path):
+        file_number += 1
+        new_file_name = file_name.replace('.log', f"_{str(file_number)}.log")
+        new_path = pathmaker(new_dir_path, new_file_name)
+    return new_path
 
 
 def log_folderer(in_log_file_name, in_main_log_folder=None):
